.. _Part2:

-----------
Development
-----------

This part is about developing web applications with the *CubicWeb* framework.

.. toctree::
   :maxdepth: 2
   :numbered:

   cubes/index
   vreg.rst
   datamodel/index
   entityclasses/index
   devcore/index
   devweb/index
   devrepo/index
   testing.rst
   migration.rst
   profiling.rst
